"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .actionusage import ActionUsage, ActionUsageTypedDict
from .apierror import APIError
from .apikey import APIKey, APIKeyTypedDict
from .apikeyupdate import APIKeyUpdate, APIKeyUpdateTypedDict
from .assetfeatures import AssetFeatures, AssetFeaturesTypedDict
from .assetresponse import (
    AssetResponse,
    AssetResponseTypedDict,
    FileData,
    FileDataTypedDict,
    Metadata,
    MetadataTypedDict,
)
from .assets_model_searchquery import (
    AssetsModelSearchQuery,
    AssetsModelSearchQueryTypedDict,
)
from .assetupdate import AssetUpdate, AssetUpdateTypedDict, Mode
from .assignmentconfig import AssignmentConfig, AssignmentConfigTypedDict
from .assignmentmode import AssignmentMode
from .availablemodels import AvailableModels
from .availablemodelsresponse import (
    AvailableModelsResponse,
    AvailableModelsResponseTypedDict,
)
from .boolindexparams import BoolIndexParams, BoolIndexParamsTypedDict
from .classificationmatch import ClassificationMatch, ClassificationMatchTypedDict
from .classificationwithfeature import (
    ClassificationWithFeature,
    ClassificationWithFeatureTypedDict,
)
from .classify_features_v1_entities_taxonomies_taxonomy_classify_postop import (
    ClassifyFeaturesV1EntitiesTaxonomiesTaxonomyClassifyPostRequest,
    ClassifyFeaturesV1EntitiesTaxonomiesTaxonomyClassifyPostRequestTypedDict,
)
from .collectionmodel import (
    CollectionModel,
    CollectionModelMetadata,
    CollectionModelMetadataTypedDict,
    CollectionModelTypedDict,
)
from .collectionresult import (
    CollectionResult,
    CollectionResultMetadata,
    CollectionResultMetadataTypedDict,
    CollectionResultTypedDict,
)
from .create_api_key_v1_organizations_users_user_email_api_keys_postop import (
    CreateAPIKeyV1OrganizationsUsersUserEmailAPIKeysPostRequest,
    CreateAPIKeyV1OrganizationsUsersUserEmailAPIKeysPostRequestTypedDict,
)
from .create_collection_v1_collections_postop import (
    CreateCollectionV1CollectionsPostRequest,
    CreateCollectionV1CollectionsPostRequestTypedDict,
)
from .create_taxonomy_v1_entities_taxonomies_postop import (
    CreateTaxonomyV1EntitiesTaxonomiesPostRequest,
    CreateTaxonomyV1EntitiesTaxonomiesPostRequestTypedDict,
)
from .createcollectionrequest import (
    CreateCollectionRequest,
    CreateCollectionRequestMetadata,
    CreateCollectionRequestMetadataTypedDict,
    CreateCollectionRequestTypedDict,
)
from .createnamespacerequest import (
    CreateNamespaceRequest,
    CreateNamespaceRequestTypedDict,
)
from .datetimeindexparams import DatetimeIndexParams, DatetimeIndexParamsTypedDict
from .dateusage import DateUsage, DateUsageTypedDict
from .db_model_paginationresponse import (
    DbModelPaginationResponse,
    DbModelPaginationResponseTypedDict,
)
from .delete_api_key_v1_organizations_users_user_email_api_keys_key_name_deleteop import (
    DeleteAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNameDeleteRequest,
    DeleteAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNameDeleteRequestTypedDict,
)
from .delete_asset_v1_assets_asset_id_deleteop import (
    DeleteAssetV1AssetsAssetIDDeleteRequest,
    DeleteAssetV1AssetsAssetIDDeleteRequestTypedDict,
)
from .delete_classifications_v1_entities_taxonomies_taxonomy_classifications_classification_id_deleteop import (
    DeleteClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsClassificationIDDeleteRequest,
    DeleteClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsClassificationIDDeleteRequestTypedDict,
)
from .delete_collection_v1_collections_collection_deleteop import (
    DeleteCollectionV1CollectionsCollectionDeleteRequest,
    DeleteCollectionV1CollectionsCollectionDeleteRequestTypedDict,
)
from .delete_feature_v1_features_feature_id_deleteop import (
    DeleteFeatureV1FeaturesFeatureIDDeleteRequest,
    DeleteFeatureV1FeaturesFeatureIDDeleteRequestTypedDict,
)
from .delete_namespace_v1_namespaces_namespace_deleteop import (
    DeleteNamespaceV1NamespacesNamespaceDeleteRequest,
    DeleteNamespaceV1NamespacesNamespaceDeleteRequestTypedDict,
)
from .delete_taxonomy_v1_entities_taxonomies_taxonomy_deleteop import (
    DeleteTaxonomyV1EntitiesTaxonomiesTaxonomyDeleteRequest,
    DeleteTaxonomyV1EntitiesTaxonomiesTaxonomyDeleteRequestTypedDict,
)
from .delete_user_v1_organizations_users_user_email_deleteop import (
    DeleteUserV1OrganizationsUsersUserEmailDeleteRequest,
    DeleteUserV1OrganizationsUsersUserEmailDeleteRequestTypedDict,
)
from .denseembedding import DenseEmbedding, DenseEmbeddingTypedDict
from .discoverrequest import DiscoverRequest, DiscoverRequestTypedDict
from .embeddingconfig import (
    EmbeddingConfig,
    EmbeddingConfigType,
    EmbeddingConfigTypedDict,
)
from .embeddingrequest import EmbeddingRequest, EmbeddingRequestTypedDict
from .embeddingresponse import (
    Embedding,
    EmbeddingResponse,
    EmbeddingResponseTypedDict,
    EmbeddingTypedDict,
)
from .entitysettings import EntitySettings, EntitySettingsTypedDict
from .errordetail import Details, DetailsTypedDict, ErrorDetail, ErrorDetailTypedDict
from .errorresponse import ErrorResponse, ErrorResponseData
from .featureextractionembeddingrequest import (
    FeatureExtractionEmbeddingRequest,
    FeatureExtractionEmbeddingRequestTypedDict,
)
from .featureoptions import FeatureOptions, FeatureOptionsTypedDict
from .featureresponse import FeatureResponse, FeatureResponseTypedDict
from .features_model_paginationresponse import (
    FeaturesModelPaginationResponse,
    FeaturesModelPaginationResponseTypedDict,
)
from .featureupdaterequest import (
    FeatureUpdateRequest,
    FeatureUpdateRequestMetadata,
    FeatureUpdateRequestMetadataTypedDict,
    FeatureUpdateRequestTypedDict,
)
from .filtercondition import FilterCondition, FilterConditionTypedDict, Operator
from .floatindexparams import FloatIndexParams, FloatIndexParamsTypedDict
from .full_asset_update_v1_assets_asset_id_putop import (
    FullAssetUpdateV1AssetsAssetIDPutRequest,
    FullAssetUpdateV1AssetsAssetIDPutRequestTypedDict,
)
from .full_feature_update_v1_features_feature_id_putop import (
    FullFeatureUpdateV1FeaturesFeatureIDPutRequest,
    FullFeatureUpdateV1FeaturesFeatureIDPutRequestTypedDict,
)
from .genericsuccessresponse import (
    GenericSuccessResponse,
    GenericSuccessResponseTypedDict,
)
from .geoindexparams import GeoIndexParams, GeoIndexParamsTypedDict
from .get_asset_v1_assets_asset_id_getop import (
    GetAssetV1AssetsAssetIDGetRequest,
    GetAssetV1AssetsAssetIDGetRequestTypedDict,
)
from .get_asset_with_features_v1_assets_asset_id_features_getop import (
    GetAssetWithFeaturesV1AssetsAssetIDFeaturesGetRequest,
    GetAssetWithFeaturesV1AssetsAssetIDFeaturesGetRequestTypedDict,
)
from .get_collection_v1_collections_collection_getop import (
    GetCollectionV1CollectionsCollectionGetRequest,
    GetCollectionV1CollectionsCollectionGetRequestTypedDict,
)
from .get_feature_v1_features_feature_id_getop import (
    GetFeatureV1FeaturesFeatureIDGetRequest,
    GetFeatureV1FeaturesFeatureIDGetRequestTypedDict,
)
from .get_namespace_v1_namespaces_namespace_getop import (
    GetNamespaceV1NamespacesNamespaceGetRequest,
    GetNamespaceV1NamespacesNamespaceGetRequestTypedDict,
)
from .get_task_v1_tasks_task_id_getop import (
    GetTaskV1TasksTaskIDGetRequest,
    GetTaskV1TasksTaskIDGetRequestTypedDict,
)
from .get_taxonomy_node_v1_entities_taxonomies_nodes_node_getop import (
    GetTaxonomyNodeV1EntitiesTaxonomiesNodesNodeGetRequest,
    GetTaxonomyNodeV1EntitiesTaxonomiesNodesNodeGetRequestTypedDict,
)
from .get_taxonomy_v1_entities_taxonomies_taxonomy_getop import (
    GetTaxonomyV1EntitiesTaxonomiesTaxonomyGetRequest,
    GetTaxonomyV1EntitiesTaxonomiesTaxonomyGetRequestTypedDict,
)
from .get_user_v1_organizations_users_user_email_getop import (
    GetUserV1OrganizationsUsersUserEmailGetRequest,
    GetUserV1OrganizationsUsersUserEmailGetRequestTypedDict,
)
from .groupbyoptions import GroupByOptions, GroupByOptionsTypedDict
from .groupbyoptionsasset import GroupByOptionsAsset, GroupByOptionsAssetTypedDict
from .groupedassetdata import GroupedAssetData, GroupedAssetDataTypedDict
from .healthcheckresponse import HealthCheckResponse, HealthCheckResponseTypedDict
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .imagedescribesettings import (
    ImageDescribeSettings,
    ImageDescribeSettingsJSONOutput,
    ImageDescribeSettingsJSONOutputTypedDict,
    ImageDescribeSettingsTypedDict,
)
from .imagedetectsettings import ImageDetectSettings, ImageDetectSettingsTypedDict
from .imagereadsettings import (
    ImageReadSettings,
    ImageReadSettingsJSONOutput,
    ImageReadSettingsJSONOutputTypedDict,
    ImageReadSettingsTypedDict,
)
from .imagesettings import ImageSettings, ImageSettingsTypedDict
from .ingest_image_url_v1_ingest_images_url_postop import (
    IngestImageURLV1IngestImagesURLPostRequest,
    IngestImageURLV1IngestImagesURLPostRequestTypedDict,
)
from .ingest_text_v1_ingest_text_postop import (
    IngestTextV1IngestTextPostRequest,
    IngestTextV1IngestTextPostRequestTypedDict,
)
from .ingest_video_url_v1_ingest_videos_url_postop import (
    IngestVideoURLV1IngestVideosURLPostRequest,
    IngestVideoURLV1IngestVideosURLPostRequestTypedDict,
)
from .inputtype import InputType
from .integerindexparams import IntegerIndexParams, IntegerIndexParamsTypedDict
from .jsonimageoutputsettings import (
    JSONImageOutputSettings,
    JSONImageOutputSettingsResponseShape,
    JSONImageOutputSettingsResponseShapeTypedDict,
    JSONImageOutputSettingsTypedDict,
)
from .jsontextoutputsettings import (
    JSONTextOutputSettings,
    JSONTextOutputSettingsTypedDict,
    ResponseShape,
    ResponseShapeTypedDict,
)
from .jsonvideooutputsettings import (
    JSONVideoOutputSettings,
    JSONVideoOutputSettingsResponseShape,
    JSONVideoOutputSettingsResponseShapeTypedDict,
    JSONVideoOutputSettingsTypedDict,
)
from .keywordindexparams import KeywordIndexParams, KeywordIndexParamsTypedDict
from .kill_task_v1_tasks_task_id_deleteop import (
    KillTaskV1TasksTaskIDDeleteRequest,
    KillTaskV1TasksTaskIDDeleteRequestTypedDict,
)
from .list_active_tasks_v1_tasks_getop import (
    ListActiveTasksV1TasksGetRequest,
    ListActiveTasksV1TasksGetRequestTypedDict,
)
from .list_assets_v1_assets_postop import (
    ListAssetsV1AssetsPostRequest,
    ListAssetsV1AssetsPostRequestTypedDict,
)
from .list_classifications_v1_entities_taxonomies_taxonomy_classifications_postop import (
    ListClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsPostRequest,
    ListClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsPostRequestTypedDict,
)
from .list_collections_v1_collections_getop import (
    ListCollectionsV1CollectionsGetRequest,
    ListCollectionsV1CollectionsGetRequestTypedDict,
)
from .list_features_v1_features_postop import (
    ListFeaturesV1FeaturesPostRequest,
    ListFeaturesV1FeaturesPostRequestTypedDict,
)
from .list_taxonomies_v1_entities_taxonomies_getop import (
    ListTaxonomiesV1EntitiesTaxonomiesGetRequest,
    ListTaxonomiesV1EntitiesTaxonomiesGetRequestTypedDict,
)
from .listassetsrequest import ListAssetsRequest, ListAssetsRequestTypedDict
from .listassetsresponse import ListAssetsResponse, ListAssetsResponseTypedDict
from .listclassificationsrequest import (
    ListClassificationsRequest,
    ListClassificationsRequestTypedDict,
)
from .listclassificationsresponse import (
    ListClassificationsResponse,
    ListClassificationsResponseTypedDict,
)
from .listcollectionsresponse import (
    ListCollectionsResponse,
    ListCollectionsResponseTypedDict,
)
from .listfeaturesrequest import ListFeaturesRequest, ListFeaturesRequestTypedDict
from .listfeaturesresponse import ListFeaturesResponse, ListFeaturesResponseTypedDict
from .listtasksresponse import ListTasksResponse, ListTasksResponseTypedDict
from .listtaxonomiesresponse import (
    ListTaxonomiesResponse,
    ListTaxonomiesResponseTypedDict,
)
from .logicaloperator import (
    And,
    AndTypedDict,
    LogicalOperator,
    LogicalOperatorTypedDict,
    Nor,
    NorTypedDict,
    Or,
    OrTypedDict,
)
from .logodetectsettings import LogoDetectSettings, LogoDetectSettingsTypedDict
from .modality import Modality
from .modeldetails import ModelDetails, ModelDetailsTypedDict
from .namespaceresponse import NamespaceResponse, NamespaceResponseTypedDict
from .nodeoptions import NodeOptions, NodeOptionsTypedDict
from .nodeupdate import NodeUpdate, NodeUpdateTypedDict
from .organizationmodel import (
    OrganizationModel,
    OrganizationModelMetadata,
    OrganizationModelMetadataTypedDict,
    OrganizationModelTypedDict,
)
from .partial_asset_update_v1_assets_asset_id_patchop import (
    PartialAssetUpdateV1AssetsAssetIDPatchRequest,
    PartialAssetUpdateV1AssetsAssetIDPatchRequestTypedDict,
)
from .payloadindexconfig import (
    FieldSchema,
    FieldSchemaTypedDict,
    PayloadIndexConfig,
    PayloadIndexConfigTypedDict,
)
from .payloadindextype import PayloadIndexType, PayloadIndexTypeTypedDict
from .payloadschematype import PayloadSchemaType
from .permission import Permission
from .processimageurlinput import (
    ProcessImageURLInput,
    ProcessImageURLInputMetadata,
    ProcessImageURLInputMetadataTypedDict,
    ProcessImageURLInputTypedDict,
)
from .processtextinput import (
    ProcessTextInput,
    ProcessTextInputMetadata,
    ProcessTextInputMetadataTypedDict,
    ProcessTextInputTypedDict,
)
from .processvideourlinput import (
    ProcessVideoURLInput,
    ProcessVideoURLInputMetadata,
    ProcessVideoURLInputMetadataTypedDict,
    ProcessVideoURLInputTypedDict,
)
from .querysettings import QuerySettings, QuerySettingsTypedDict
from .rerankingoptions import RerankingOptions, RerankingOptionsTypedDict
from .search_assets_v1_assets_search_postop import (
    SearchAssetsV1AssetsSearchPostRequest,
    SearchAssetsV1AssetsSearchPostRequestTypedDict,
)
from .search_features_v1_features_search_postop import (
    SearchFeaturesV1FeaturesSearchPostRequest,
    SearchFeaturesV1FeaturesSearchPostRequestTypedDict,
    SearchFeaturesV1FeaturesSearchPostResponseSearchFeaturesV1FeaturesSearchPost,
    SearchFeaturesV1FeaturesSearchPostResponseSearchFeaturesV1FeaturesSearchPostTypedDict,
)
from .search_model_searchquery import (
    SearchModelSearchQuery,
    SearchModelSearchQueryTypedDict,
    Type,
)
from .searchassetsrequest import SearchAssetsRequest, SearchAssetsRequestTypedDict
from .searchrequestfeatures import SearchRequestFeatures, SearchRequestFeaturesTypedDict
from .security import Security, SecurityTypedDict
from .sortoption import Direction, SortOption, SortOptionTypedDict
from .sparseembedding import SparseEmbedding, SparseEmbeddingTypedDict
from .taskresponse import TaskResponse, TaskResponseTypedDict
from .taskstatus import TaskStatus
from .taxonomycreate import TaxonomyCreate, TaxonomyCreateTypedDict
from .taxonomyextractionconfig import (
    TaxonomyExtractionConfig,
    TaxonomyExtractionConfigTypedDict,
)
from .taxonomymodel import TaxonomyModel, TaxonomyModelTypedDict
from .taxonomynode import TaxonomyNode, TaxonomyNodeTypedDict
from .taxonomynodecreate import TaxonomyNodeCreate, TaxonomyNodeCreateTypedDict
from .taxonomyupdate import TaxonomyUpdate, TaxonomyUpdateTypedDict
from .textindexparams import TextIndexParams, TextIndexParamsTypedDict
from .textsettings import TextSettings, TextSettingsTypedDict
from .tokenizertype import TokenizerType
from .update_api_key_v1_organizations_users_user_email_api_keys_key_name_patchop import (
    UpdateAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNamePatchRequest,
    UpdateAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNamePatchRequestTypedDict,
)
from .update_collection_v1_collections_collection_putop import (
    UpdateCollectionV1CollectionsCollectionPutRequest,
    UpdateCollectionV1CollectionsCollectionPutRequestTypedDict,
)
from .update_namespace_v1_namespaces_namespace_putop import (
    UpdateNamespaceV1NamespacesNamespacePutRequest,
    UpdateNamespaceV1NamespacesNamespacePutRequestTypedDict,
)
from .update_node_v1_entities_taxonomies_nodes_node_patchop import (
    UpdateNodeV1EntitiesTaxonomiesNodesNodePatchRequest,
    UpdateNodeV1EntitiesTaxonomiesNodesNodePatchRequestTypedDict,
)
from .update_taxonomy_v1_entities_taxonomies_taxonomy_patchop import (
    UpdateTaxonomyV1EntitiesTaxonomiesTaxonomyPatchRequest,
    UpdateTaxonomyV1EntitiesTaxonomiesTaxonomyPatchRequestTypedDict,
)
from .updateassetrequest import (
    UpdateAssetRequest,
    UpdateAssetRequestMetadata,
    UpdateAssetRequestMetadataTypedDict,
    UpdateAssetRequestTypedDict,
)
from .updatenamespacerequest import (
    UpdateNamespaceRequest,
    UpdateNamespaceRequestTypedDict,
)
from .usage import Usage, UsageTypedDict
from .usermodel_input import (
    UserModelInput,
    UserModelInputMetadata,
    UserModelInputMetadataTypedDict,
    UserModelInputTypedDict,
)
from .usermodel_output import (
    UserModelOutput,
    UserModelOutputMetadata,
    UserModelOutputMetadataTypedDict,
    UserModelOutputTypedDict,
)
from .uuidindexparams import UUIDIndexParams, UUIDIndexParamsTypedDict
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .vectormodel import VectorModel
from .vectortype import VectorType
from .videodescribesettings import (
    VideoDescribeSettings,
    VideoDescribeSettingsJSONOutput,
    VideoDescribeSettingsJSONOutputTypedDict,
    VideoDescribeSettingsTypedDict,
)
from .videodetectsettings import VideoDetectSettings, VideoDetectSettingsTypedDict
from .videoreadsettings import (
    JSONOutput,
    JSONOutputTypedDict,
    VideoReadSettings,
    VideoReadSettingsTypedDict,
)
from .videosettings import VideoSettings, VideoSettingsTypedDict
from .videotranscriptionsettings import (
    VideoTranscriptionSettings,
    VideoTranscriptionSettingsJSONOutput,
    VideoTranscriptionSettingsJSONOutputTypedDict,
    VideoTranscriptionSettingsTypedDict,
)


__all__ = [
    "APIError",
    "APIKey",
    "APIKeyTypedDict",
    "APIKeyUpdate",
    "APIKeyUpdateTypedDict",
    "ActionUsage",
    "ActionUsageTypedDict",
    "And",
    "AndTypedDict",
    "AssetFeatures",
    "AssetFeaturesTypedDict",
    "AssetResponse",
    "AssetResponseTypedDict",
    "AssetUpdate",
    "AssetUpdateTypedDict",
    "AssetsModelSearchQuery",
    "AssetsModelSearchQueryTypedDict",
    "AssignmentConfig",
    "AssignmentConfigTypedDict",
    "AssignmentMode",
    "AvailableModels",
    "AvailableModelsResponse",
    "AvailableModelsResponseTypedDict",
    "BoolIndexParams",
    "BoolIndexParamsTypedDict",
    "ClassificationMatch",
    "ClassificationMatchTypedDict",
    "ClassificationWithFeature",
    "ClassificationWithFeatureTypedDict",
    "ClassifyFeaturesV1EntitiesTaxonomiesTaxonomyClassifyPostRequest",
    "ClassifyFeaturesV1EntitiesTaxonomiesTaxonomyClassifyPostRequestTypedDict",
    "CollectionModel",
    "CollectionModelMetadata",
    "CollectionModelMetadataTypedDict",
    "CollectionModelTypedDict",
    "CollectionResult",
    "CollectionResultMetadata",
    "CollectionResultMetadataTypedDict",
    "CollectionResultTypedDict",
    "CreateAPIKeyV1OrganizationsUsersUserEmailAPIKeysPostRequest",
    "CreateAPIKeyV1OrganizationsUsersUserEmailAPIKeysPostRequestTypedDict",
    "CreateCollectionRequest",
    "CreateCollectionRequestMetadata",
    "CreateCollectionRequestMetadataTypedDict",
    "CreateCollectionRequestTypedDict",
    "CreateCollectionV1CollectionsPostRequest",
    "CreateCollectionV1CollectionsPostRequestTypedDict",
    "CreateNamespaceRequest",
    "CreateNamespaceRequestTypedDict",
    "CreateTaxonomyV1EntitiesTaxonomiesPostRequest",
    "CreateTaxonomyV1EntitiesTaxonomiesPostRequestTypedDict",
    "DateUsage",
    "DateUsageTypedDict",
    "DatetimeIndexParams",
    "DatetimeIndexParamsTypedDict",
    "DbModelPaginationResponse",
    "DbModelPaginationResponseTypedDict",
    "DeleteAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNameDeleteRequest",
    "DeleteAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNameDeleteRequestTypedDict",
    "DeleteAssetV1AssetsAssetIDDeleteRequest",
    "DeleteAssetV1AssetsAssetIDDeleteRequestTypedDict",
    "DeleteClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsClassificationIDDeleteRequest",
    "DeleteClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsClassificationIDDeleteRequestTypedDict",
    "DeleteCollectionV1CollectionsCollectionDeleteRequest",
    "DeleteCollectionV1CollectionsCollectionDeleteRequestTypedDict",
    "DeleteFeatureV1FeaturesFeatureIDDeleteRequest",
    "DeleteFeatureV1FeaturesFeatureIDDeleteRequestTypedDict",
    "DeleteNamespaceV1NamespacesNamespaceDeleteRequest",
    "DeleteNamespaceV1NamespacesNamespaceDeleteRequestTypedDict",
    "DeleteTaxonomyV1EntitiesTaxonomiesTaxonomyDeleteRequest",
    "DeleteTaxonomyV1EntitiesTaxonomiesTaxonomyDeleteRequestTypedDict",
    "DeleteUserV1OrganizationsUsersUserEmailDeleteRequest",
    "DeleteUserV1OrganizationsUsersUserEmailDeleteRequestTypedDict",
    "DenseEmbedding",
    "DenseEmbeddingTypedDict",
    "Details",
    "DetailsTypedDict",
    "Direction",
    "DiscoverRequest",
    "DiscoverRequestTypedDict",
    "Embedding",
    "EmbeddingConfig",
    "EmbeddingConfigType",
    "EmbeddingConfigTypedDict",
    "EmbeddingRequest",
    "EmbeddingRequestTypedDict",
    "EmbeddingResponse",
    "EmbeddingResponseTypedDict",
    "EmbeddingTypedDict",
    "EntitySettings",
    "EntitySettingsTypedDict",
    "ErrorDetail",
    "ErrorDetailTypedDict",
    "ErrorResponse",
    "ErrorResponseData",
    "FeatureExtractionEmbeddingRequest",
    "FeatureExtractionEmbeddingRequestTypedDict",
    "FeatureOptions",
    "FeatureOptionsTypedDict",
    "FeatureResponse",
    "FeatureResponseTypedDict",
    "FeatureUpdateRequest",
    "FeatureUpdateRequestMetadata",
    "FeatureUpdateRequestMetadataTypedDict",
    "FeatureUpdateRequestTypedDict",
    "FeaturesModelPaginationResponse",
    "FeaturesModelPaginationResponseTypedDict",
    "FieldSchema",
    "FieldSchemaTypedDict",
    "FileData",
    "FileDataTypedDict",
    "FilterCondition",
    "FilterConditionTypedDict",
    "FloatIndexParams",
    "FloatIndexParamsTypedDict",
    "FullAssetUpdateV1AssetsAssetIDPutRequest",
    "FullAssetUpdateV1AssetsAssetIDPutRequestTypedDict",
    "FullFeatureUpdateV1FeaturesFeatureIDPutRequest",
    "FullFeatureUpdateV1FeaturesFeatureIDPutRequestTypedDict",
    "GenericSuccessResponse",
    "GenericSuccessResponseTypedDict",
    "GeoIndexParams",
    "GeoIndexParamsTypedDict",
    "GetAssetV1AssetsAssetIDGetRequest",
    "GetAssetV1AssetsAssetIDGetRequestTypedDict",
    "GetAssetWithFeaturesV1AssetsAssetIDFeaturesGetRequest",
    "GetAssetWithFeaturesV1AssetsAssetIDFeaturesGetRequestTypedDict",
    "GetCollectionV1CollectionsCollectionGetRequest",
    "GetCollectionV1CollectionsCollectionGetRequestTypedDict",
    "GetFeatureV1FeaturesFeatureIDGetRequest",
    "GetFeatureV1FeaturesFeatureIDGetRequestTypedDict",
    "GetNamespaceV1NamespacesNamespaceGetRequest",
    "GetNamespaceV1NamespacesNamespaceGetRequestTypedDict",
    "GetTaskV1TasksTaskIDGetRequest",
    "GetTaskV1TasksTaskIDGetRequestTypedDict",
    "GetTaxonomyNodeV1EntitiesTaxonomiesNodesNodeGetRequest",
    "GetTaxonomyNodeV1EntitiesTaxonomiesNodesNodeGetRequestTypedDict",
    "GetTaxonomyV1EntitiesTaxonomiesTaxonomyGetRequest",
    "GetTaxonomyV1EntitiesTaxonomiesTaxonomyGetRequestTypedDict",
    "GetUserV1OrganizationsUsersUserEmailGetRequest",
    "GetUserV1OrganizationsUsersUserEmailGetRequestTypedDict",
    "GroupByOptions",
    "GroupByOptionsAsset",
    "GroupByOptionsAssetTypedDict",
    "GroupByOptionsTypedDict",
    "GroupedAssetData",
    "GroupedAssetDataTypedDict",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "HealthCheckResponse",
    "HealthCheckResponseTypedDict",
    "ImageDescribeSettings",
    "ImageDescribeSettingsJSONOutput",
    "ImageDescribeSettingsJSONOutputTypedDict",
    "ImageDescribeSettingsTypedDict",
    "ImageDetectSettings",
    "ImageDetectSettingsTypedDict",
    "ImageReadSettings",
    "ImageReadSettingsJSONOutput",
    "ImageReadSettingsJSONOutputTypedDict",
    "ImageReadSettingsTypedDict",
    "ImageSettings",
    "ImageSettingsTypedDict",
    "IngestImageURLV1IngestImagesURLPostRequest",
    "IngestImageURLV1IngestImagesURLPostRequestTypedDict",
    "IngestTextV1IngestTextPostRequest",
    "IngestTextV1IngestTextPostRequestTypedDict",
    "IngestVideoURLV1IngestVideosURLPostRequest",
    "IngestVideoURLV1IngestVideosURLPostRequestTypedDict",
    "InputType",
    "IntegerIndexParams",
    "IntegerIndexParamsTypedDict",
    "JSONImageOutputSettings",
    "JSONImageOutputSettingsResponseShape",
    "JSONImageOutputSettingsResponseShapeTypedDict",
    "JSONImageOutputSettingsTypedDict",
    "JSONOutput",
    "JSONOutputTypedDict",
    "JSONTextOutputSettings",
    "JSONTextOutputSettingsTypedDict",
    "JSONVideoOutputSettings",
    "JSONVideoOutputSettingsResponseShape",
    "JSONVideoOutputSettingsResponseShapeTypedDict",
    "JSONVideoOutputSettingsTypedDict",
    "KeywordIndexParams",
    "KeywordIndexParamsTypedDict",
    "KillTaskV1TasksTaskIDDeleteRequest",
    "KillTaskV1TasksTaskIDDeleteRequestTypedDict",
    "ListActiveTasksV1TasksGetRequest",
    "ListActiveTasksV1TasksGetRequestTypedDict",
    "ListAssetsRequest",
    "ListAssetsRequestTypedDict",
    "ListAssetsResponse",
    "ListAssetsResponseTypedDict",
    "ListAssetsV1AssetsPostRequest",
    "ListAssetsV1AssetsPostRequestTypedDict",
    "ListClassificationsRequest",
    "ListClassificationsRequestTypedDict",
    "ListClassificationsResponse",
    "ListClassificationsResponseTypedDict",
    "ListClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsPostRequest",
    "ListClassificationsV1EntitiesTaxonomiesTaxonomyClassificationsPostRequestTypedDict",
    "ListCollectionsResponse",
    "ListCollectionsResponseTypedDict",
    "ListCollectionsV1CollectionsGetRequest",
    "ListCollectionsV1CollectionsGetRequestTypedDict",
    "ListFeaturesRequest",
    "ListFeaturesRequestTypedDict",
    "ListFeaturesResponse",
    "ListFeaturesResponseTypedDict",
    "ListFeaturesV1FeaturesPostRequest",
    "ListFeaturesV1FeaturesPostRequestTypedDict",
    "ListTasksResponse",
    "ListTasksResponseTypedDict",
    "ListTaxonomiesResponse",
    "ListTaxonomiesResponseTypedDict",
    "ListTaxonomiesV1EntitiesTaxonomiesGetRequest",
    "ListTaxonomiesV1EntitiesTaxonomiesGetRequestTypedDict",
    "Loc",
    "LocTypedDict",
    "LogicalOperator",
    "LogicalOperatorTypedDict",
    "LogoDetectSettings",
    "LogoDetectSettingsTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "Modality",
    "Mode",
    "ModelDetails",
    "ModelDetailsTypedDict",
    "NamespaceResponse",
    "NamespaceResponseTypedDict",
    "NodeOptions",
    "NodeOptionsTypedDict",
    "NodeUpdate",
    "NodeUpdateTypedDict",
    "Nor",
    "NorTypedDict",
    "Operator",
    "Or",
    "OrTypedDict",
    "OrganizationModel",
    "OrganizationModelMetadata",
    "OrganizationModelMetadataTypedDict",
    "OrganizationModelTypedDict",
    "PartialAssetUpdateV1AssetsAssetIDPatchRequest",
    "PartialAssetUpdateV1AssetsAssetIDPatchRequestTypedDict",
    "PayloadIndexConfig",
    "PayloadIndexConfigTypedDict",
    "PayloadIndexType",
    "PayloadIndexTypeTypedDict",
    "PayloadSchemaType",
    "Permission",
    "ProcessImageURLInput",
    "ProcessImageURLInputMetadata",
    "ProcessImageURLInputMetadataTypedDict",
    "ProcessImageURLInputTypedDict",
    "ProcessTextInput",
    "ProcessTextInputMetadata",
    "ProcessTextInputMetadataTypedDict",
    "ProcessTextInputTypedDict",
    "ProcessVideoURLInput",
    "ProcessVideoURLInputMetadata",
    "ProcessVideoURLInputMetadataTypedDict",
    "ProcessVideoURLInputTypedDict",
    "QuerySettings",
    "QuerySettingsTypedDict",
    "RerankingOptions",
    "RerankingOptionsTypedDict",
    "ResponseShape",
    "ResponseShapeTypedDict",
    "SearchAssetsRequest",
    "SearchAssetsRequestTypedDict",
    "SearchAssetsV1AssetsSearchPostRequest",
    "SearchAssetsV1AssetsSearchPostRequestTypedDict",
    "SearchFeaturesV1FeaturesSearchPostRequest",
    "SearchFeaturesV1FeaturesSearchPostRequestTypedDict",
    "SearchFeaturesV1FeaturesSearchPostResponseSearchFeaturesV1FeaturesSearchPost",
    "SearchFeaturesV1FeaturesSearchPostResponseSearchFeaturesV1FeaturesSearchPostTypedDict",
    "SearchModelSearchQuery",
    "SearchModelSearchQueryTypedDict",
    "SearchRequestFeatures",
    "SearchRequestFeaturesTypedDict",
    "Security",
    "SecurityTypedDict",
    "SortOption",
    "SortOptionTypedDict",
    "SparseEmbedding",
    "SparseEmbeddingTypedDict",
    "TaskResponse",
    "TaskResponseTypedDict",
    "TaskStatus",
    "TaxonomyCreate",
    "TaxonomyCreateTypedDict",
    "TaxonomyExtractionConfig",
    "TaxonomyExtractionConfigTypedDict",
    "TaxonomyModel",
    "TaxonomyModelTypedDict",
    "TaxonomyNode",
    "TaxonomyNodeCreate",
    "TaxonomyNodeCreateTypedDict",
    "TaxonomyNodeTypedDict",
    "TaxonomyUpdate",
    "TaxonomyUpdateTypedDict",
    "TextIndexParams",
    "TextIndexParamsTypedDict",
    "TextSettings",
    "TextSettingsTypedDict",
    "TokenizerType",
    "Type",
    "UUIDIndexParams",
    "UUIDIndexParamsTypedDict",
    "UpdateAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNamePatchRequest",
    "UpdateAPIKeyV1OrganizationsUsersUserEmailAPIKeysKeyNamePatchRequestTypedDict",
    "UpdateAssetRequest",
    "UpdateAssetRequestMetadata",
    "UpdateAssetRequestMetadataTypedDict",
    "UpdateAssetRequestTypedDict",
    "UpdateCollectionV1CollectionsCollectionPutRequest",
    "UpdateCollectionV1CollectionsCollectionPutRequestTypedDict",
    "UpdateNamespaceRequest",
    "UpdateNamespaceRequestTypedDict",
    "UpdateNamespaceV1NamespacesNamespacePutRequest",
    "UpdateNamespaceV1NamespacesNamespacePutRequestTypedDict",
    "UpdateNodeV1EntitiesTaxonomiesNodesNodePatchRequest",
    "UpdateNodeV1EntitiesTaxonomiesNodesNodePatchRequestTypedDict",
    "UpdateTaxonomyV1EntitiesTaxonomiesTaxonomyPatchRequest",
    "UpdateTaxonomyV1EntitiesTaxonomiesTaxonomyPatchRequestTypedDict",
    "Usage",
    "UsageTypedDict",
    "UserModelInput",
    "UserModelInputMetadata",
    "UserModelInputMetadataTypedDict",
    "UserModelInputTypedDict",
    "UserModelOutput",
    "UserModelOutputMetadata",
    "UserModelOutputMetadataTypedDict",
    "UserModelOutputTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "VectorModel",
    "VectorType",
    "VideoDescribeSettings",
    "VideoDescribeSettingsJSONOutput",
    "VideoDescribeSettingsJSONOutputTypedDict",
    "VideoDescribeSettingsTypedDict",
    "VideoDetectSettings",
    "VideoDetectSettingsTypedDict",
    "VideoReadSettings",
    "VideoReadSettingsTypedDict",
    "VideoSettings",
    "VideoSettingsTypedDict",
    "VideoTranscriptionSettings",
    "VideoTranscriptionSettingsJSONOutput",
    "VideoTranscriptionSettingsJSONOutputTypedDict",
    "VideoTranscriptionSettingsTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .groupbyoptionsasset import GroupByOptionsAsset, GroupByOptionsAssetTypedDict
from .logicaloperator import LogicalOperator, LogicalOperatorTypedDict
from .sortoption import SortOption, SortOptionTypedDict
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class ListAssetsRequestTypedDict(TypedDict):
    collections: List[str]
    r"""List of Collection IDs or Names to search within, required"""
    filters: NotRequired[Nullable[LogicalOperatorTypedDict]]
    r"""Used for filtering across all indexes"""
    group_by: NotRequired[Nullable[GroupByOptionsAssetTypedDict]]
    r"""Grouping options for search results"""
    sort: NotRequired[Nullable[SortOptionTypedDict]]
    r"""List of fields to sort by, with direction (asc or desc). Supports dot notation for nested fields."""
    select: NotRequired[Nullable[List[str]]]
    r"""List of fields to return in results, supports dot notation. If None, all fields are returned."""
    return_url: NotRequired[Nullable[bool]]
    r"""Return the presigned URL for the asset and preview asset, this will introduce additional latency"""


class ListAssetsRequest(BaseModel):
    collections: List[str]
    r"""List of Collection IDs or Names to search within, required"""

    filters: OptionalNullable[LogicalOperator] = UNSET
    r"""Used for filtering across all indexes"""

    group_by: OptionalNullable[GroupByOptionsAsset] = UNSET
    r"""Grouping options for search results"""

    sort: OptionalNullable[SortOption] = UNSET
    r"""List of fields to sort by, with direction (asc or desc). Supports dot notation for nested fields."""

    select: OptionalNullable[List[str]] = UNSET
    r"""List of fields to return in results, supports dot notation. If None, all fields are returned."""

    return_url: OptionalNullable[bool] = UNSET
    r"""Return the presigned URL for the asset and preview asset, this will introduce additional latency"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["filters", "group_by", "sort", "select", "return_url"]
        nullable_fields = ["filters", "group_by", "sort", "select", "return_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sortoption import SortOption, SortOptionTypedDict
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class GroupByOptionsTypedDict(TypedDict):
    field: NotRequired[Nullable[str]]
    r"""
    Field to group by

    Note: We currently do not support ad-hoc grouping.
    This means the field must be indexed separately.
    Please contact us to add additional fields for grouping.

    """
    max_features: NotRequired[Nullable[int]]
    r"""Maximum number of features to group"""
    sort: NotRequired[Nullable[SortOptionTypedDict]]
    r"""Sort options for ordering the inside of the groups"""


class GroupByOptions(BaseModel):
    field: OptionalNullable[str] = UNSET
    r"""
    Field to group by

    Note: We currently do not support ad-hoc grouping.
    This means the field must be indexed separately.
    Please contact us to add additional fields for grouping.

    """

    max_features: OptionalNullable[int] = UNSET
    r"""Maximum number of features to group"""

    sort: OptionalNullable[SortOption] = UNSET
    r"""Sort options for ordering the inside of the groups"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["field", "max_features", "sort"]
        nullable_fields = ["field", "max_features", "sort"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .featureresponse import FeatureResponse, FeatureResponseTypedDict
from .features_model_paginationresponse import (
    FeaturesModelPaginationResponse,
    FeaturesModelPaginationResponseTypedDict,
)
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListFeaturesResponseTypedDict(TypedDict):
    results: List[FeatureResponseTypedDict]
    pagination: FeaturesModelPaginationResponseTypedDict


class ListFeaturesResponse(BaseModel):
    results: List[FeatureResponse]

    pagination: FeaturesModelPaginationResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .embeddingrequest import EmbeddingRequest, EmbeddingRequestTypedDict
from .entitysettings import EntitySettings, EntitySettingsTypedDict
from .jsonvideooutputsettings import (
    JSONVideoOutputSettings,
    JSONVideoOutputSettingsTypedDict,
)
from .videodescribesettings import VideoDescribeSettings, VideoDescribeSettingsTypedDict
from .videodetectsettings import VideoDetectSettings, VideoDetectSettingsTypedDict
from .videoreadsettings import VideoReadSettings, VideoReadSettingsTypedDict
from .videotranscriptionsettings import (
    VideoTranscriptionSettings,
    VideoTranscriptionSettingsTypedDict,
)
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class VideoSettingsTypedDict(TypedDict):
    interval_sec: NotRequired[int]
    r"""Interval in seconds for processing video. Must be greater than or equal to 5, less than 120."""
    read: NotRequired[Nullable[VideoReadSettingsTypedDict]]
    r"""Settings for reading and analyzing video content."""
    embed: NotRequired[List[EmbeddingRequestTypedDict]]
    r"""List of embedding settings for generating multiple embeddings. For now, if url is provided, value must be None.
    Default: [{type: 'url', embedding_model: 'multimodal'}] if none provided.
    """
    transcribe: NotRequired[Nullable[VideoTranscriptionSettingsTypedDict]]
    r"""Settings for transcribing video audio."""
    describe: NotRequired[Nullable[VideoDescribeSettingsTypedDict]]
    r"""Settings for generating video descriptions."""
    detect: NotRequired[Nullable[VideoDetectSettingsTypedDict]]
    r"""Settings for object detection in video frames."""
    json_output: NotRequired[Nullable[JSONVideoOutputSettingsTypedDict]]
    r"""Settings for structured JSON output of video analysis."""
    entities: NotRequired[Nullable[EntitySettingsTypedDict]]
    r"""Settings for extracting entities from video content"""


class VideoSettings(BaseModel):
    interval_sec: Optional[int] = 10
    r"""Interval in seconds for processing video. Must be greater than or equal to 5, less than 120."""

    read: OptionalNullable[VideoReadSettings] = UNSET
    r"""Settings for reading and analyzing video content."""

    embed: Optional[List[EmbeddingRequest]] = None
    r"""List of embedding settings for generating multiple embeddings. For now, if url is provided, value must be None.
    Default: [{type: 'url', embedding_model: 'multimodal'}] if none provided.
    """

    transcribe: OptionalNullable[VideoTranscriptionSettings] = UNSET
    r"""Settings for transcribing video audio."""

    describe: OptionalNullable[VideoDescribeSettings] = UNSET
    r"""Settings for generating video descriptions."""

    detect: OptionalNullable[VideoDetectSettings] = UNSET
    r"""Settings for object detection in video frames."""

    json_output: OptionalNullable[JSONVideoOutputSettings] = UNSET
    r"""Settings for structured JSON output of video analysis."""

    entities: OptionalNullable[EntitySettings] = UNSET
    r"""Settings for extracting entities from video content"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "interval_sec",
            "read",
            "embed",
            "transcribe",
            "describe",
            "detect",
            "json_output",
            "entities",
        ]
        nullable_fields = [
            "read",
            "transcribe",
            "describe",
            "detect",
            "json_output",
            "entities",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from mixpeek import models, utils
from mixpeek._hooks import HookContext
from mixpeek.types import OptionalNullable, UNSET
from mixpeek.utils import get_security_from_env
from typing import Any, Mapping, Optional


class Taxonomies(BaseSDK):
    def get(
        self,
        *,
        taxonomy: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaxonomyModel:
        r"""Get Taxonomy

        Get the complete taxonomy that contains the specified node

        :param taxonomy: The name or id of the taxonomy to find
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.GetTaxonomyV1EntitiesTaxonomiesTaxonomyGetRequest(
            taxonomy=taxonomy,
            x_namespace=x_namespace,
        )

        req = self._build_request(
            method="GET",
            path="/v1/entities/taxonomies/{taxonomy}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="get_taxonomy_v1_entities_taxonomies__taxonomy__get",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaxonomyModel)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_async(
        self,
        *,
        taxonomy: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaxonomyModel:
        r"""Get Taxonomy

        Get the complete taxonomy that contains the specified node

        :param taxonomy: The name or id of the taxonomy to find
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.GetTaxonomyV1EntitiesTaxonomiesTaxonomyGetRequest(
            taxonomy=taxonomy,
            x_namespace=x_namespace,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/entities/taxonomies/{taxonomy}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="get_taxonomy_v1_entities_taxonomies__taxonomy__get",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaxonomyModel)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def delete(
        self,
        *,
        taxonomy: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GenericSuccessResponse:
        r"""Delete Taxonomy

        Delete an existing taxonomy and remove all associated node classifications from features.

        This operation:
        - Deletes the taxonomy and all its nodes
        - Removes any node classifications associated with this taxonomy from all features
        - This action cannot be undone


        **Requirements:**
        - Required permissions: write

        :param taxonomy: The ID or name of the taxonomy to delete
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.DeleteTaxonomyV1EntitiesTaxonomiesTaxonomyDeleteRequest(
            taxonomy=taxonomy,
            x_namespace=x_namespace,
        )

        req = self._build_request(
            method="DELETE",
            path="/v1/entities/taxonomies/{taxonomy}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="delete_taxonomy_v1_entities_taxonomies__taxonomy__delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.GenericSuccessResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def delete_async(
        self,
        *,
        taxonomy: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GenericSuccessResponse:
        r"""Delete Taxonomy

        Delete an existing taxonomy and remove all associated node classifications from features.

        This operation:
        - Deletes the taxonomy and all its nodes
        - Removes any node classifications associated with this taxonomy from all features
        - This action cannot be undone


        **Requirements:**
        - Required permissions: write

        :param taxonomy: The ID or name of the taxonomy to delete
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.DeleteTaxonomyV1EntitiesTaxonomiesTaxonomyDeleteRequest(
            taxonomy=taxonomy,
            x_namespace=x_namespace,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v1/entities/taxonomies/{taxonomy}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="delete_taxonomy_v1_entities_taxonomies__taxonomy__delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.GenericSuccessResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def update(
        self,
        *,
        taxonomy: str,
        x_namespace: OptionalNullable[str] = UNSET,
        taxonomy_name: OptionalNullable[str] = UNSET,
        description: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaxonomyModel:
        r"""Update Taxonomy

        Update an existing taxonomy's metadata

        **Requirements:**
        - Required permissions: write

        :param taxonomy: The ID or name of the taxonomy to update
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param taxonomy_name: Updated taxonomy name (must not contain spaces or special characters)
        :param description: Updated taxonomy description
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.UpdateTaxonomyV1EntitiesTaxonomiesTaxonomyPatchRequest(
            taxonomy=taxonomy,
            x_namespace=x_namespace,
            taxonomy_update=models.TaxonomyUpdate(
                taxonomy_name=taxonomy_name,
                description=description,
            ),
        )

        req = self._build_request(
            method="PATCH",
            path="/v1/entities/taxonomies/{taxonomy}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.taxonomy_update, False, False, "json", models.TaxonomyUpdate
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="update_taxonomy_v1_entities_taxonomies__taxonomy__patch",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaxonomyModel)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def update_async(
        self,
        *,
        taxonomy: str,
        x_namespace: OptionalNullable[str] = UNSET,
        taxonomy_name: OptionalNullable[str] = UNSET,
        description: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaxonomyModel:
        r"""Update Taxonomy

        Update an existing taxonomy's metadata

        **Requirements:**
        - Required permissions: write

        :param taxonomy: The ID or name of the taxonomy to update
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param taxonomy_name: Updated taxonomy name (must not contain spaces or special characters)
        :param description: Updated taxonomy description
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.UpdateTaxonomyV1EntitiesTaxonomiesTaxonomyPatchRequest(
            taxonomy=taxonomy,
            x_namespace=x_namespace,
            taxonomy_update=models.TaxonomyUpdate(
                taxonomy_name=taxonomy_name,
                description=description,
            ),
        )

        req = self._build_request_async(
            method="PATCH",
            path="/v1/entities/taxonomies/{taxonomy}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.taxonomy_update, False, False, "json", models.TaxonomyUpdate
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="update_taxonomy_v1_entities_taxonomies__taxonomy__patch",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaxonomyModel)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import ConfigDict, model_serializer
from typing import Any, Dict
from typing_extensions import NotRequired, TypedDict


class FeatureResponseTypedDict(TypedDict):
    url: NotRequired[Nullable[str]]
    r"""The presigned URL for accessing the asset"""
    preview_url: NotRequired[Nullable[str]]
    r"""The presigned URL for accessing the asset preview"""
    duplicate_of: NotRequired[Nullable[str]]
    r"""The asset_id of the asset that this asset is a duplicate of"""


class FeatureResponse(BaseModel):
    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Any] = pydantic.Field(init=False)

    url: OptionalNullable[str] = UNSET
    r"""The presigned URL for accessing the asset"""

    preview_url: OptionalNullable[str] = UNSET
    r"""The presigned URL for accessing the asset preview"""

    duplicate_of: OptionalNullable[str] = UNSET
    r"""The asset_id of the asset that this asset is a duplicate of"""

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["url", "preview_url", "duplicate_of"]
        nullable_fields = ["url", "preview_url", "duplicate_of"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        for k, v in serialized.items():
            m[k] = v

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SparseEmbeddingTypedDict(TypedDict):
    indices: List[int]
    r"""Indices for sparse vector"""
    values: List[float]
    r"""Values for sparse vector"""


class SparseEmbedding(BaseModel):
    indices: List[int]
    r"""Indices for sparse vector"""

    values: List[float]
    r"""Values for sparse vector"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class DenseEmbeddingTypedDict(TypedDict):
    vector: List[float]
    r"""Dense vector representation"""


class DenseEmbedding(BaseModel):
    vector: List[float]
    r"""Dense vector representation"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputtype import InputType
from .vectormodel import VectorModel
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class EmbeddingRequestTypedDict(TypedDict):
    r"""
    Request model for embedding generation.

    When multiple EmbeddingRequests use the same embedding_model:
    - All inputs will be embedded in the same vector space
    - The final embedding will be the average of all individual embeddings
    - Original values will be stored with a ' | ' separator

    Example:
    Two requests with same model \"clip\":
    1. type: \"text\", value: \"a dog\", embedding_model: \"clip\"
    2. type: \"url\", value: \"https://example.com/image.jpg\", embedding_model: \"clip\"

    Result:
    - vectors[\"clip\"] = average of both embeddings
    - embedding_configs[\"clip\"] = \"a dog | https://example.com/image.jpg\"

    """

    type: InputType
    embedding_model: VectorModel
    value: NotRequired[Nullable[str]]
    r"""The input content to embed. Could be a URL, text content, file path, or base64 encoded string"""


class EmbeddingRequest(BaseModel):
    r"""
    Request model for embedding generation.

    When multiple EmbeddingRequests use the same embedding_model:
    - All inputs will be embedded in the same vector space
    - The final embedding will be the average of all individual embeddings
    - Original values will be stored with a ' | ' separator

    Example:
    Two requests with same model \"clip\":
    1. type: \"text\", value: \"a dog\", embedding_model: \"clip\"
    2. type: \"url\", value: \"https://example.com/image.jpg\", embedding_model: \"clip\"

    Result:
    - vectors[\"clip\"] = average of both embeddings
    - embedding_configs[\"clip\"] = \"a dog | https://example.com/image.jpg\"

    """

    type: InputType

    embedding_model: VectorModel

    value: OptionalNullable[str] = UNSET
    r"""The input content to embed. Could be a URL, text content, file path, or base64 encoded string"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["value"]
        nullable_fields = ["value"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from mixpeek import models, utils
from mixpeek._hooks import HookContext
from mixpeek.types import OptionalNullable, UNSET
from mixpeek.utils import get_security_from_env
from typing import Any, Mapping, Optional


class Tasks(BaseSDK):
    def delete(
        self,
        *,
        task_id: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Kill Task

        **Requirements:**
        - Required permissions: write

        :param task_id:
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.KillTaskV1TasksTaskIDDeleteRequest(
            task_id=task_id,
            x_namespace=x_namespace,
        )

        req = self._build_request(
            method="DELETE",
            path="/v1/tasks/{task_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="kill_task_v1_tasks__task_id__delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Any)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def delete_async(
        self,
        *,
        task_id: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Kill Task

        **Requirements:**
        - Required permissions: write

        :param task_id:
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.KillTaskV1TasksTaskIDDeleteRequest(
            task_id=task_id,
            x_namespace=x_namespace,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v1/tasks/{task_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="kill_task_v1_tasks__task_id__delete",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Any)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get(
        self,
        *,
        task_id: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Get Task Information

        Retrieve a task by its ID.

        A task may have an expiration time, after which it will still be returned but marked as expired.
        This allows tracking of historical tasks while indicating their current validity state.

        :param task_id:
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.GetTaskV1TasksTaskIDGetRequest(
            task_id=task_id,
            x_namespace=x_namespace,
        )

        req = self._build_request(
            method="GET",
            path="/v1/tasks/{task_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="get_task_v1_tasks__task_id__get",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_async(
        self,
        *,
        task_id: str,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Get Task Information

        Retrieve a task by its ID.

        A task may have an expiration time, after which it will still be returned but marked as expired.
        This allows tracking of historical tasks while indicating their current validity state.

        :param task_id:
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.GetTaskV1TasksTaskIDGetRequest(
            task_id=task_id,
            x_namespace=x_namespace,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/tasks/{task_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="get_task_v1_tasks__task_id__get",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def list_active(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        page_size: Optional[int] = 10,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListTasksResponse:
        r"""List Active Tasks

        Retrieve all tasks that are not in a complete state (DONE, FAILED, SKIPPED, or CANCELLED)

        :param page:
        :param page_size:
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.ListActiveTasksV1TasksGetRequest(
            page=page,
            page_size=page_size,
            x_namespace=x_namespace,
        )

        req = self._build_request(
            method="GET",
            path="/v1/tasks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="list_active_tasks_v1_tasks_get",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.ListTasksResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_active_async(
        self,
        *,
        page: OptionalNullable[int] = UNSET,
        page_size: Optional[int] = 10,
        x_namespace: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListTasksResponse:
        r"""List Active Tasks

        Retrieve all tasks that are not in a complete state (DONE, FAILED, SKIPPED, or CANCELLED)

        :param page:
        :param page_size:
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.ListActiveTasksV1TasksGetRequest(
            page=page,
            page_size=page_size,
            x_namespace=x_namespace,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/tasks",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="list_active_tasks_v1_tasks_get",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.ListTasksResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from typing_extensions import TypedDict


class HealthCheckResponseTypedDict(TypedDict):
    status: str


class HealthCheckResponse(BaseModel):
    status: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, HeaderMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GlobalsTypedDict(TypedDict):
    x_namespace: NotRequired[str]
    r"""Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint."""


class Globals(BaseModel):
    x_namespace: Annotated[
        Optional[str],
        pydantic.Field(alias="x-namespace"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

# pyright: reportReturnType = false
from typing_extensions import Protocol, runtime_checkable
import httpx
from typing import Any, Optional, Union


@runtime_checkable
class HttpClient(Protocol):
    def send(
        self,
        request: httpx.Request,
        *,
        stream: bool = False,
        auth: Union[
            httpx._types.AuthTypes, httpx._client.UseClientDefault, None
        ] = httpx.USE_CLIENT_DEFAULT,
        follow_redirects: Union[
            bool, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
    ) -> httpx.Response:
        pass

    def build_request(
        self,
        method: str,
        url: httpx._types.URLTypes,
        *,
        content: Optional[httpx._types.RequestContent] = None,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        params: Optional[httpx._types.QueryParamTypes] = None,
        headers: Optional[httpx._types.HeaderTypes] = None,
        cookies: Optional[httpx._types.CookieTypes] = None,
        timeout: Union[
            httpx._types.TimeoutTypes, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
        extensions: Optional[httpx._types.RequestExtensions] = None,
    ) -> httpx.Request:
        pass

    def close(self) -> None:
        pass


@runtime_checkable
class AsyncHttpClient(Protocol):
    async def send(
        self,
        request: httpx.Request,
        *,
        stream: bool = False,
        auth: Union[
            httpx._types.AuthTypes, httpx._client.UseClientDefault, None
        ] = httpx.USE_CLIENT_DEFAULT,
        follow_redirects: Union[
            bool, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
    ) -> httpx.Response:
        pass

    def build_request(
        self,
        method: str,
        url: httpx._types.URLTypes,
        *,
        content: Optional[httpx._types.RequestContent] = None,
        data: Optional[httpx._types.RequestData] = None,
        files: Optional[httpx._types.RequestFiles] = None,
        json: Optional[Any] = None,
        params: Optional[httpx._types.QueryParamTypes] = None,
        headers: Optional[httpx._types.HeaderTypes] = None,
        cookies: Optional[httpx._types.CookieTypes] = None,
        timeout: Union[
            httpx._types.TimeoutTypes, httpx._client.UseClientDefault
        ] = httpx.USE_CLIENT_DEFAULT,
        extensions: Optional[httpx._types.RequestExtensions] = None,
    ) -> httpx.Request:
        pass

    async def aclose(self) -> None:
        pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from mixpeek import models, utils
from mixpeek._hooks import HookContext
from mixpeek.types import OptionalNullable, UNSET
from mixpeek.utils import get_security_from_env
from typing import Any, List, Mapping, Optional, Union


class IngestAssets(BaseSDK):
    def ingest_text(
        self,
        *,
        collection: str,
        x_namespace: OptionalNullable[str] = UNSET,
        asset_update: OptionalNullable[
            Union[models.AssetUpdate, models.AssetUpdateTypedDict]
        ] = UNSET,
        metadata: Optional[
            Union[
                models.ProcessTextInputMetadata,
                models.ProcessTextInputMetadataTypedDict,
            ]
        ] = None,
        feature_extractors: OptionalNullable[
            Union[models.TextSettings, models.TextSettingsTypedDict]
        ] = UNSET,
        skip_duplicate: OptionalNullable[bool] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Ingest Text

        **Requirements:**
        - Required permissions: write

        :param collection: Unique identifier for the collection where the processed asset will be stored, can be the collection name or collection ID. If neither exist, the collection will be created.
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param asset_update: Controls how processing results are stored - either creating a new asset or updating an existing one.
        :param metadata: Additional metadata associated with the file. Can include any key-value pairs relevant to the file.
        :param feature_extractors: Settings for text processing.
        :param skip_duplicate: Skips processing when a duplicate hash is found and stores an error by the task_id with the existing asset_id
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IngestTextV1IngestTextPostRequest(
            x_namespace=x_namespace,
            process_text_input=models.ProcessTextInput(
                collection=collection,
                asset_update=utils.get_pydantic_model(
                    asset_update, OptionalNullable[models.AssetUpdate]
                ),
                metadata=utils.get_pydantic_model(
                    metadata, Optional[models.ProcessTextInputMetadata]
                ),
                feature_extractors=utils.get_pydantic_model(
                    feature_extractors, OptionalNullable[models.TextSettings]
                ),
                skip_duplicate=skip_duplicate,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1/ingest/text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.process_text_input,
                False,
                False,
                "json",
                models.ProcessTextInput,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="ingest_text_v1_ingest_text_post",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def ingest_text_async(
        self,
        *,
        collection: str,
        x_namespace: OptionalNullable[str] = UNSET,
        asset_update: OptionalNullable[
            Union[models.AssetUpdate, models.AssetUpdateTypedDict]
        ] = UNSET,
        metadata: Optional[
            Union[
                models.ProcessTextInputMetadata,
                models.ProcessTextInputMetadataTypedDict,
            ]
        ] = None,
        feature_extractors: OptionalNullable[
            Union[models.TextSettings, models.TextSettingsTypedDict]
        ] = UNSET,
        skip_duplicate: OptionalNullable[bool] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Ingest Text

        **Requirements:**
        - Required permissions: write

        :param collection: Unique identifier for the collection where the processed asset will be stored, can be the collection name or collection ID. If neither exist, the collection will be created.
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param asset_update: Controls how processing results are stored - either creating a new asset or updating an existing one.
        :param metadata: Additional metadata associated with the file. Can include any key-value pairs relevant to the file.
        :param feature_extractors: Settings for text processing.
        :param skip_duplicate: Skips processing when a duplicate hash is found and stores an error by the task_id with the existing asset_id
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IngestTextV1IngestTextPostRequest(
            x_namespace=x_namespace,
            process_text_input=models.ProcessTextInput(
                collection=collection,
                asset_update=utils.get_pydantic_model(
                    asset_update, OptionalNullable[models.AssetUpdate]
                ),
                metadata=utils.get_pydantic_model(
                    metadata, Optional[models.ProcessTextInputMetadata]
                ),
                feature_extractors=utils.get_pydantic_model(
                    feature_extractors, OptionalNullable[models.TextSettings]
                ),
                skip_duplicate=skip_duplicate,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/ingest/text",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.process_text_input,
                False,
                False,
                "json",
                models.ProcessTextInput,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="ingest_text_v1_ingest_text_post",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def ingest_video_url(
        self,
        *,
        url: str,
        collection: str,
        x_namespace: OptionalNullable[str] = UNSET,
        asset_update: OptionalNullable[
            Union[models.AssetUpdate, models.AssetUpdateTypedDict]
        ] = UNSET,
        metadata: Optional[
            Union[
                models.ProcessVideoURLInputMetadata,
                models.ProcessVideoURLInputMetadataTypedDict,
            ]
        ] = None,
        skip_duplicate: OptionalNullable[bool] = UNSET,
        feature_extractors: OptionalNullable[
            Union[List[models.VideoSettings], List[models.VideoSettingsTypedDict]]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Ingest Video Url

        **Requirements:**
        - Required permissions: write

        :param url: The URL of the asset to be processed. Must be a valid HTTP or HTTPS URL.
        :param collection: Unique identifier for the collection where the processed asset will be stored, can be the collection name or collection ID. If neither exist, the collection will be created.
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param asset_update: Controls how processing results are stored - either creating a new asset or updating an existing one.
        :param metadata: Additional metadata associated with the asset. Can include any key-value pairs relevant to the asset.
        :param skip_duplicate: Makes feature extraction idempotent. When True and a duplicate file hash is found, copies features from the existing asset instead of reprocessing. This allows the same file to be used multiple times with different metadata while avoiding redundant processing.
        :param feature_extractors: Settings for video processing. Only applicable if the URL points to a video file.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IngestVideoURLV1IngestVideosURLPostRequest(
            x_namespace=x_namespace,
            process_video_url_input=models.ProcessVideoURLInput(
                url=url,
                collection=collection,
                asset_update=utils.get_pydantic_model(
                    asset_update, OptionalNullable[models.AssetUpdate]
                ),
                metadata=utils.get_pydantic_model(
                    metadata, Optional[models.ProcessVideoURLInputMetadata]
                ),
                skip_duplicate=skip_duplicate,
                feature_extractors=utils.get_pydantic_model(
                    feature_extractors, OptionalNullable[List[models.VideoSettings]]
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1/ingest/videos/url",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.process_video_url_input,
                False,
                False,
                "json",
                models.ProcessVideoURLInput,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="ingest_video_url_v1_ingest_videos_url_post",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def ingest_video_url_async(
        self,
        *,
        url: str,
        collection: str,
        x_namespace: OptionalNullable[str] = UNSET,
        asset_update: OptionalNullable[
            Union[models.AssetUpdate, models.AssetUpdateTypedDict]
        ] = UNSET,
        metadata: Optional[
            Union[
                models.ProcessVideoURLInputMetadata,
                models.ProcessVideoURLInputMetadataTypedDict,
            ]
        ] = None,
        skip_duplicate: OptionalNullable[bool] = UNSET,
        feature_extractors: OptionalNullable[
            Union[List[models.VideoSettings], List[models.VideoSettingsTypedDict]]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Ingest Video Url

        **Requirements:**
        - Required permissions: write

        :param url: The URL of the asset to be processed. Must be a valid HTTP or HTTPS URL.
        :param collection: Unique identifier for the collection where the processed asset will be stored, can be the collection name or collection ID. If neither exist, the collection will be created.
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param asset_update: Controls how processing results are stored - either creating a new asset or updating an existing one.
        :param metadata: Additional metadata associated with the asset. Can include any key-value pairs relevant to the asset.
        :param skip_duplicate: Makes feature extraction idempotent. When True and a duplicate file hash is found, copies features from the existing asset instead of reprocessing. This allows the same file to be used multiple times with different metadata while avoiding redundant processing.
        :param feature_extractors: Settings for video processing. Only applicable if the URL points to a video file.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IngestVideoURLV1IngestVideosURLPostRequest(
            x_namespace=x_namespace,
            process_video_url_input=models.ProcessVideoURLInput(
                url=url,
                collection=collection,
                asset_update=utils.get_pydantic_model(
                    asset_update, OptionalNullable[models.AssetUpdate]
                ),
                metadata=utils.get_pydantic_model(
                    metadata, Optional[models.ProcessVideoURLInputMetadata]
                ),
                skip_duplicate=skip_duplicate,
                feature_extractors=utils.get_pydantic_model(
                    feature_extractors, OptionalNullable[List[models.VideoSettings]]
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/ingest/videos/url",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.process_video_url_input,
                False,
                False,
                "json",
                models.ProcessVideoURLInput,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="ingest_video_url_v1_ingest_videos_url_post",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def ingest_image_url(
        self,
        *,
        url: str,
        collection: str,
        x_namespace: OptionalNullable[str] = UNSET,
        asset_update: OptionalNullable[
            Union[models.AssetUpdate, models.AssetUpdateTypedDict]
        ] = UNSET,
        metadata: Optional[
            Union[
                models.ProcessImageURLInputMetadata,
                models.ProcessImageURLInputMetadataTypedDict,
            ]
        ] = None,
        skip_duplicate: OptionalNullable[bool] = UNSET,
        feature_extractors: OptionalNullable[
            Union[models.ImageSettings, models.ImageSettingsTypedDict]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Ingest Image Url

        **Requirements:**
        - Required permissions: write

        :param url: The URL of the asset to be processed. Must be a valid HTTP or HTTPS URL.
        :param collection: Unique identifier for the collection where the processed asset will be stored, can be the collection name or collection ID. If neither exist, the collection will be created.
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param asset_update: Controls how processing results are stored - either creating a new asset or updating an existing one.
        :param metadata: Additional metadata associated with the asset. Can include any key-value pairs relevant to the asset.
        :param skip_duplicate: Makes feature extraction idempotent. When True and a duplicate file hash is found, copies features from the existing asset instead of reprocessing. This allows the same file to be used multiple times with different metadata while avoiding redundant processing.
        :param feature_extractors: Settings for image processing. Only applicable if the URL points to an image file.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IngestImageURLV1IngestImagesURLPostRequest(
            x_namespace=x_namespace,
            process_image_url_input=models.ProcessImageURLInput(
                url=url,
                collection=collection,
                asset_update=utils.get_pydantic_model(
                    asset_update, OptionalNullable[models.AssetUpdate]
                ),
                metadata=utils.get_pydantic_model(
                    metadata, Optional[models.ProcessImageURLInputMetadata]
                ),
                skip_duplicate=skip_duplicate,
                feature_extractors=utils.get_pydantic_model(
                    feature_extractors, OptionalNullable[models.ImageSettings]
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1/ingest/images/url",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.process_image_url_input,
                False,
                False,
                "json",
                models.ProcessImageURLInput,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="ingest_image_url_v1_ingest_images_url_post",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def ingest_image_url_async(
        self,
        *,
        url: str,
        collection: str,
        x_namespace: OptionalNullable[str] = UNSET,
        asset_update: OptionalNullable[
            Union[models.AssetUpdate, models.AssetUpdateTypedDict]
        ] = UNSET,
        metadata: Optional[
            Union[
                models.ProcessImageURLInputMetadata,
                models.ProcessImageURLInputMetadataTypedDict,
            ]
        ] = None,
        skip_duplicate: OptionalNullable[bool] = UNSET,
        feature_extractors: OptionalNullable[
            Union[models.ImageSettings, models.ImageSettingsTypedDict]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TaskResponse:
        r"""Ingest Image Url

        **Requirements:**
        - Required permissions: write

        :param url: The URL of the asset to be processed. Must be a valid HTTP or HTTPS URL.
        :param collection: Unique identifier for the collection where the processed asset will be stored, can be the collection name or collection ID. If neither exist, the collection will be created.
        :param x_namespace: Optional namespace for data isolation. This can be a namespace name or namespace ID. Example: 'netflix_prod' or 'ns_1234567890'. To create a namespace, use the /namespaces endpoint.
        :param asset_update: Controls how processing results are stored - either creating a new asset or updating an existing one.
        :param metadata: Additional metadata associated with the asset. Can include any key-value pairs relevant to the asset.
        :param skip_duplicate: Makes feature extraction idempotent. When True and a duplicate file hash is found, copies features from the existing asset instead of reprocessing. This allows the same file to be used multiple times with different metadata while avoiding redundant processing.
        :param feature_extractors: Settings for image processing. Only applicable if the URL points to an image file.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IngestImageURLV1IngestImagesURLPostRequest(
            x_namespace=x_namespace,
            process_image_url_input=models.ProcessImageURLInput(
                url=url,
                collection=collection,
                asset_update=utils.get_pydantic_model(
                    asset_update, OptionalNullable[models.AssetUpdate]
                ),
                metadata=utils.get_pydantic_model(
                    metadata, Optional[models.ProcessImageURLInputMetadata]
                ),
                skip_duplicate=skip_duplicate,
                feature_extractors=utils.get_pydantic_model(
                    feature_extractors, OptionalNullable[models.ImageSettings]
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/ingest/images/url",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.process_image_url_input,
                False,
                False,
                "json",
                models.ProcessImageURLInput,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="ingest_image_url_v1_ingest_images_url_post",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TaskResponse)
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.HTTPValidationErrorData)
            raise models.HTTPValidationError(data=data)
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorResponseData)
            raise models.ErrorResponse(data=data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .taxonomynode import TaxonomyNode, TaxonomyNodeTypedDict
from mixpeek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TaxonomyModelTypedDict(TypedDict):
    taxonomy_name: str
    r"""Taxonomy name"""
    nodes: List[TaxonomyNodeTypedDict]
    r"""Taxonomy nodes"""
    taxonomy_id: NotRequired[str]
    r"""Auto-generated taxonomy identifier"""


class TaxonomyModel(BaseModel):
    taxonomy_name: str
    r"""Taxonomy name"""

    nodes: List[TaxonomyNode]
    r"""Taxonomy nodes"""

    taxonomy_id: Optional[str] = None
    r"""Auto-generated taxonomy identifier"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .availablemodels import AvailableModels
from .logicaloperator import LogicalOperator, LogicalOperatorTypedDict
from .querysettings import QuerySettings, QuerySettingsTypedDict
from enum import Enum
from mixpeek.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class Type(str, Enum):
    r"""Type of input (text, url, or base64)"""

    TEXT = "text"
    URL = "url"
    BASE64 = "base64"


class SearchModelSearchQueryTypedDict(TypedDict):
    embedding_model: AvailableModels
    value: str
    r"""Query value - can be text, URL, or base64 encoded image"""
    type: Type
    r"""Type of input (text, url, or base64)"""
    filters: NotRequired[Nullable[LogicalOperatorTypedDict]]
    r"""Optional filters for the query, this is used for filtering individual vector indexes"""
    settings: NotRequired[Nullable[QuerySettingsTypedDict]]
    r"""Optional settings for this specific query"""


class SearchModelSearchQuery(BaseModel):
    embedding_model: AvailableModels

    value: str
    r"""Query value - can be text, URL, or base64 encoded image"""

    type: Type
    r"""Type of input (text, url, or base64)"""

    filters: OptionalNullable[LogicalOperator] = UNSET
    r"""Optional filters for the query, this is used for filtering individual vector indexes"""

    settings: OptionalNullable[QuerySettings] = UNSET
    r"""Optional settings for this specific query"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["filters", "settings"]
        nullable_fields = ["filters", "settings"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .classificationwithfeature import (
    ClassificationWithFeature,
    ClassificationWithFeatureTypedDict,
)
from .db_model_paginationresponse import (
    DbModelPaginationResponse,
    DbModelPaginationResponseTypedDict,
)
from mixpeek.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListClassificationsResponseTypedDict(TypedDict):
    r"""Response for the list classifications endpoint"""

    results: List[ClassificationWithFeatureTypedDict]
    r"""List of classification entries with optional enriched data"""
    pagination: DbModelPaginationResponseTypedDict


class ListClassificationsResponse(BaseModel):
    r"""Response for the list classifications endpoint"""

    results: List[ClassificationWithFeature]
    r"""List of classification entries with optional enriched data"""

    pagination: DbModelPaginationResponse
